%define anolis_release 2
Summary:       Library of functions for manipulating TIFF format image files
Name:          libtiff
Version:       4.6.0
Release:       %{anolis_release}%{?dist}
License:       libtiff
URL:           http://www.simplesystems.org/libtiff/

Source:        http://download.osgeo.org/libtiff/tiff-%{version}.tar.gz

BuildRequires: gcc, gcc-c++
BuildRequires: zlib-devel libjpeg-devel jbigkit-devel libzstd-devel libwebp-devel glut-devel xz-devel
BuildRequires: python3-sphinx
BuildRequires: cmake

# https://gitlab.com/libtiff/libtiff/-/commit/3705f82b6483c7906cf08cd6b9dcdcd59c61d779
Patch0:        libtiff-4.6.0-CVE-2024-7006.patch

# https://gitlab.com/libtiff/libtiff/-/commit/5320c9d89c054fa805d037d84c57da874470b01a
Patch1:        CVE-2023-6277.patch
# https://gitlab.com/libtiff/libtiff/-/commit/1e7d217a323eac701b134afc4ae39b6bdfdbc96a
Patch2:        CVE-2023-6228.patch

# https://gitlab.com/libtiff/libtiff/-/commit/51558511bdbbcffdce534db21dbaf5d54b31638a
Patch3:        Fix-CVE-2023-52356.patch

%description
The libtiff package contains a library of functions for manipulating
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:       Development tools for programs which will use the libtiff library
Requires:      %{name} = %{version}-%{release}

%description devel
This package contains the header files and documentation necessary for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.

%package static
Summary:     Static TIFF image format file library
Requires:    %{name}-devel = %{version}-%{release}

%description static
The libtiff-static package contains the statically linkable version of libtiff.
Linking to static libraries is discouraged for most applications, but it is
necessary for some boot packages.

%package tools
Summary:    Command-line utility programs for manipulating TIFF files
Requires:   %{name} = %{version}-%{release}

%description tools
This package contains command-line programs for manipulating TIFF format
image files using the libtiff library.

%prep
%autosetup -p1 -n tiff-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake
%cmake_build

%install
%cmake_install

# remove what we didn't want installed
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/

%generate_compatibility_deps

%check
%ctest

%files
%dir %{abidir}
%license LICENSE.md
%{_libdir}/libtiff.so.*
%{_libdir}/libtiffxx.so.*
%{abidir}/libtiff*.dump

%files doc
%doc README.md RELEASE-DATE VERSION

%files devel
%doc TODO ChangeLog doc/html-prebuilt/*
%{_includedir}/*
%{_libdir}/libtiff.so
%{_libdir}/libtiffxx.so
%{_libdir}/pkgconfig/libtiff*.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/tiff
%{_mandir}/man3/*

%files tools
%{_bindir}/tiffcp
%{_bindir}/tiffdump
%{_bindir}/tiffinfo
%{_bindir}/tiffset
%{_bindir}/tiffsplit
%{abidir}/tiffcp-option.list
%{abidir}/tiffinfo-option.list
%{abidir}/tiffsplit-option.list
%{_mandir}/man1/tiffcp.1*
%{_mandir}/man1/tiffdump.1*
%{_mandir}/man1/tiffinfo.1*
%{_mandir}/man1/tiffset.1*
%{_mandir}/man1/tiffsplit.1*

%changelog
* Fri Mar 14 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.6.0-2
- to #IAGL52
- Add patch to fix CVE-2023-52356
- project: TC2024080204
- Signed-off-by: mgb01105731 <mgb01105731@alibaba-inc.com>

* Wed Feb 19 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.6.0-1
- Update to 4.6.0 from 4.5.1
- Remove libtiff-opengl by reason of tiffgt been removed
- Fix CVE-2023-52355
- Add patches to fix CVE-2024-7006
- Remove patch as the new version of tarball already includes changes.
- Remove patches as this version removes a big number of utilities that 
  have suffered from lack of maintenance over the years
  [Patches cherry-pick from c10s. Original changelog:
  - fix CVE-2024-7006 a null pointer dereference in tif_dirinfo(4.6.0-4)]

* Thu Jan 04 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.5.1-5
- Fix CVE-2023-6228

* Tue Nov 28 2023 Funda Wang <fundawang@yeah.net> - 4.5.1-4
- Fix CVE-2023-6277

* Tue Oct 31 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.5.1-3
- Fix CVE-2023-1916

* Tue Oct 17 2023 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 4.5.1-2
- Fix CVE-2023-41175 CVE-2023-40745

* Wed Jun 14 2023 Funda Wang <fundawang@yeah.net> - 4.5.1-1
- New version 4.5.1

* Sat Mar 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-3
- Add patches fixing CVE-2023-0975 .. 0804

* Sat Feb 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-2
- Add patch fixing CVE-2022-48281

* Wed Jan 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-1
- New version 4.5.0
- Build using cmake
- Drop static as cmake does not support building it right now
- Split out tiffgt as what debian does

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.4.0-2
- optimise spec file & add doc package

* Mon Sep 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 4.4.0-1
- update to 4.4.0

* Tue Apr 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.3.0-2
- fix tiffconf.h error

* Fri Apr 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.3.0-1
- Init from upstream version 4.3.0
